@@ -1,8 +1,9 @@
-__version__ = "0.8.1"
+__version__ = "0.8.2"
 
 from pathlib import Path
 
 from docutils import nodes
+from sphinx.util.docutils import SphinxDirective
 from sphinx.util import logging
 
 from jupyter_sphinx.ast import (  # noqa: F401
@@ -21,7 +22,14 @@ from .parser import (
 )
 from .transform import CellOutputsToNodes
 from .nb_glue import glue  # noqa: F401
-from .nb_glue.domain import NbGlueDomain
+
+from .nb_glue.domain import (
+    NbGlueDomain,
+    PasteMathNode,
+    PasteNode,
+    PasteTextNode,
+    PasteInlineNode,
+)
 from .nb_glue.transform import PasteNodesToDocutils
 
 LOGGER = logging.getLogger(__name__)
@@ -73,6 +81,26 @@ def save_glue_cache(app, env):
     NbGlueDomain.from_env(env).write_cache()
 
 
+class CodeCell(SphinxDirective):
+    """Raises a warning if it is triggered, it should not make it to the doctree."""
+
+    optional_arguments = 1
+    final_argument_whitespace = True
+    has_content = True
+
+    def run(self):
+        LOGGER.warning(
+            (
+                "Found a `code-cell` directive. To execute the `code-cell`, you must "
+                "add Jupytext header content to the page. See "
+                "https://myst-nb.readthedocs.io/en/latest/use/markdown.html "
+                "for more information."
+            ),
+            location=(self.env.docname, self.lineno),
+        )
+        return []
+
+
 def setup(app):
     """Initialize Sphinx extension."""
     # Allow parsing ipynb files
@@ -120,10 +148,24 @@ def setup(app):
         man=(skip, None),
     )
 
+    # Register our inline nodes so they can be parsed as a part of titles
+    # No translators should touch these nodes because we'll replace them in a transform
+    for node in [PasteMathNode, PasteNode, PasteTextNode, PasteInlineNode]:
+        app.add_node(
+            node,
+            override=True,
+            html=(skip, None),
+            latex=(skip, None),
+            textinfo=(skip, None),
+            text=(skip, None),
+            man=(skip, None),
+        )
+
     # Add configuration for the cache
     app.add_config_value("jupyter_cache", "", "env")
     app.add_config_value("execution_excludepatterns", [], "env")
     app.add_config_value("jupyter_execute_notebooks", "auto", "env")
+    app.add_config_value("execution_timeout", 30, "env")
 
     # Register our post-transform which will convert output bundles to nodes
     app.add_post_transform(PasteNodesToDocutils)
@@ -139,6 +181,7 @@ def setup(app):
     app.add_js_file("mystnb.js")
     app.setup_extension("jupyter_sphinx")
     app.add_domain(NbGlueDomain)
+    app.add_directive("code-cell", CodeCell)
 
     # TODO need to deal with key clashes in NbGlueDomain.merge_domaindata
     # before this is parallel_read_safe
